@@ -493,6 +493,10 @@ def load_data():
             if s != 'pgsql':
                 sections.append(s)
 
+        # we run through sorted section list, unless we got the section list
+        # from command line
+        sections.sort()
+
     log.info('Will consider following sections:')
     for line in myprint(sections):
         log.info(line)
@@ -500,9 +504,6 @@ def load_data():
     # we count time passed from now on
     begin = time.time()
 
-    # we run through sorted section list
-    sections.sort()
-
     threads  = {}
     started  = {}
     finished = {}
@@ -607,15 +608,15 @@ if __name__ == "__main__":
     try:
         ret = load_data()
     except Exception, e:
-        print >>STDERR, e
+        sys.stderr.write(str(e) + '\n')
         sys.exit(1)
 
     except IOError, e:
-        print >>STDERR, e
+        sys.stderr.write(str(e) + '\n')
         sys.exit(1)
 
     except KeyboardInterrupt, e:
-        print >>STDERR, e
+        sys.stderr.write(str(e) + '\n')
         sys.exit(1)
         
     sys.exit(ret)
